"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const consul_1 = __importDefault(require("consul"));
const fs_1 = require("fs");
const js_yaml_1 = __importDefault(require("js-yaml"));
async function getConsulConfig(prefix) {
    if (!prefix)
        return undefined;
    const consulClient = consul_1.default({ promisify: true });
    const keys = await consulClient.kv.keys(process.env.CONSUL_KV_PREFIX);
    const values = (await Promise.all(keys.map((key) => consulClient.kv.get(key))));
    return keys.reduce((obj, key, i) => {
        const fieldName = key.replace(prefix, "");
        const value = JSON.parse(values[i]);
        obj[fieldName] = value;
        return obj;
    }, {});
}
async function getConfig(configVars) {
    var _a, _b, _c;
    const path = process.env.CONFIG_PATH || (configVars === null || configVars === void 0 ? void 0 : configVars.configPath);
    const fileConfig = path
        ? js_yaml_1.default.safeLoad(fs_1.readFileSync(path, "utf8"))
        : undefined;
    const consulConfigKeys = await getConsulConfig(process.env.CONSUL_KV_PREFIX);
    const mergedConfig = Object.assign({}, fileConfig, consulConfigKeys, configVars);
    const mqttUri = process.env.MQTT_URI || ((_a = mergedConfig.mqtt) === null || _a === void 0 ? void 0 : _a.uri);
    if (!mqttUri) {
        throw new Error("MQTT URI Required.");
    }
    const mqttPrefix = process.env.MQTT_PREFIX || ((_b = mergedConfig.mqtt) === null || _b === void 0 ? void 0 : _b.prefix) || "";
    const httpPort = (process.env.HTTP_PORT && parseInt(process.env.HTTP_PORT)) || ((_c = mergedConfig.http) === null || _c === void 0 ? void 0 : _c.port) ||
        null;
    const mqtt = Object.assign(Object.assign({ subscriptions: [] }, mergedConfig.mqtt), { uri: mqttUri, prefix: mqttPrefix });
    const http = Object.assign(Object.assign({}, mergedConfig.http), { port: httpPort });
    const service = mergedConfig.service || {};
    return {
        mqtt,
        http,
        service,
    };
}
exports.getConfig = getConfig;
//# sourceMappingURL=config.js.map